    import vessels.proxies.HA.SSL as HA_SSL
    HA_SSL.build_papers (
    	certificate_path = "/etc/haproxy/SSL/certificate.pem",
    	key_path = "/etc/haproxy/SSL/certificate.pem.key"
    )

    import vessels.proxies.HA.configs.HTTPS_to_HTTP as HA_HTTPS_to_HTTP
    HA_HTTPS_to_HTTP.build (
    	start = "yes",

    	SSL_certificate_path = "/etc/haproxy/SSL/certificate.pem",
    	config_path = "/etc/haproxy/haproxy.cfg",

    	to_addresses = [
    		"0.0.0.0:8000",
    		"0.0.0.0:8000",
    		"0.0.0.0:8000",
    		"0.0.0.0:8000",
    		"0.0.0.0:8000",
    		"0.0.0.0:8000",
    		"0.0.0.0:8000",
    		"0.0.0.0:8000"
    	]
    )